@@ -1,4 +1,4 @@
-;;; doric-obsidian-theme.el --- Minimalist dark theme -*- lexical-binding:t -*-
+;;; doric-obsidian-theme.el --- Minimalist theme with dark grey background and rocky hues -*- lexical-binding:t -*-
 
 ;; Copyright (C) 2025  Free Software Foundation, Inc.
 
@@ -74,7 +74,7 @@
       (bg-cyan "#2f4f54"))
   "Palette of `doric-obsidian' theme.")
 
-  (doric-themes-define-theme doric-obsidian dark))
+  (doric-themes-define-theme doric-obsidian dark "Minimalist theme with dark grey background and rocky hues"))
 
 (provide 'doric-obsidian-theme)
 ;;; doric-obsidian-theme.el ends here
