@@ -705,7 +705,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     font-lock-negation-char-face
     font-lock-number-face
     font-lock-punctuation-face
-    gnus-header-content
     gnus-server-opened
     gnus-summary-high-undownloaded
     gnus-summary-high-unread
@@ -764,8 +763,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     org-archived
     org-default
     org-document-info
-    org-inline-src-block
-    org-latex-and-related
     org-mode-line-clock
     org-scheduled
     org-scheduled-today
@@ -783,7 +780,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     shortdoc-section
     so-long-mode-line-inactive
     speedbar-file-face
-    substitute-match
     tabulated-list-fake-header
     vc-dir-directory
     vc-dir-file
@@ -818,7 +814,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     consult-async-finished
     consult-async-running
     consult-async-split
-    consult-file
     css-property
     custom-face-tag
     custom-group-subtitle
@@ -859,7 +854,6 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     font-lock-regexp-grouping-backslash
     font-lock-regexp-grouping-construct
     geiser-font-lock-repl-prompt
-    git-commit-summary
     gnus-emphasis-bold
     gnus-header-content
     gnus-header-from
@@ -1196,15 +1190,21 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     ztreep-diff-model-add-face))
 
 (defconst doric-themes-diff-added-highlight-faces
-  '(ediff-current-diff-B
+  '(diff-hl-insert
+    diff-hl-dired-insert
+    ediff-current-diff-B
     magit-diff-added-highlight))
 
 (defconst doric-themes-diff-changed-highlight-faces
-  '(ediff-current-diff-C
+  '(diff-hl-change
+    diff-hl-dired-change
+    ediff-current-diff-C
     magit-diff-base-highlight))
 
 (defconst doric-themes-diff-removed-highlight-faces
-  '(ediff-current-diff-A
+  '(diff-hl-delete
+    diff-hl-dired-delete
+    ediff-current-diff-A
     magit-diff-removed-highlight))
 
 (defconst doric-themes-diff-added-refine-faces
@@ -1362,6 +1362,9 @@ default a generic text that mentions the BACKGROUND-MODE."
               `(separator-line ((t :underline ,border)))
               `(scroll-bar ((t :background ,bg-main :foreground ,border)))
               `(fill-column-indicator ((t :foreground ,bg-shadow-intense)))
+              `(minibuffer-nonselected
+                ((((supports :strike-through t)) :strike-through t)
+                 (t :inverse-video t)))
               `(tooltip ((t :background ,bg-accent :foreground ,fg-accent)))
               `(tty-menu-disabled-face ((t :background ,bg-accent :foreground ,fg-shadow-subtle)))
               `(tty-menu-enabled-face ((t :background ,bg-accent :foreground ,fg-main)))
